==> imio.smartweb.core-1.0a23.tar.gz: imio.smartweb.core-1.0a23/src/imio/smartweb/core/webcomponents/src/components/Annuaire/ContactList/ContactList.jsx <==
import ContactCard from "../ContactCard/ContactCard";
import { Link } from "react-router-dom";
import React from "react";
import removeAccents from 'remove-accents';
const ContactList = ({ contactArray, onChange, onHover, parentCallback }) => {
    function handleClick(event) {
        onChange(event);
    }

    function handleHover(event) {
        onHover(event);
    }
    return (
        <React.Fragment>
            <ul className="r-result-list annuaire-result-list">
                {contactArray.map((contactItem, i) => (
                    <li
                        key={i}
                        className="r-list-item-group"
                        onMouseEnter={() => handleHover(contactItem.UID)}
                        onMouseLeave={() => handleHover(null)}
                        onClick={() => handleClick(contactItem.UID)}
                    >
                        <Link
                            className="r-list-item-link"
                            style={{ textDecoration: "none" }}
                            to={{
                                pathname: removeAccents(contactItem.title.replace(/\s/g, '-').toLowerCase()),
                                search: `?u=${contactItem.UID}`,
                                state: {
                                    idItem: contactItem.UID,
                                },
                            }}
                        ></Link>
                        <ContactCard contactItem={contactItem} key={contactItem.created} />
                    </li>
                ))}
            </ul>
            <button className="load-more-link"
                onClick={(e) => {
                    parentCallback();
                }}
            >
                Afficher plus
            </button>
        </React.Fragment>
    );
};
export default ContactList;

==> imio.smartweb.core-1.0.3.tar.gz: imio.smartweb.core-1.0.3/src/imio/smartweb/core/webcomponents/src/components/Annuaire/ContactList/ContactList.jsx <==
import ContactCard from "../ContactCard/ContactCard";
import { Link } from "react-router-dom";
import React from "react";
import removeAccents from "remove-accents";
const ContactList = ({ contactArray, onChange, onHover, parentCallback }) => {
    function handleClick(event) {
        onChange(event);
    }

    function handleHover(event) {
        onHover(event);
    }
    return (
        <React.Fragment>
            <ul className="r-result-list annuaire-result-list">
                {contactArray.map((contactItem, i) => (
                    <li
                        key={i}
                        className="r-list-item-group"
                        onMouseEnter={() => handleHover(contactItem.UID)}
                        onMouseLeave={() => handleHover(null)}
                        onClick={() => handleClick(contactItem.UID)}
                    >
                        <Link
                            className="r-list-item-link"
                            style={{ textDecoration: "none" }}
                            to={{
                                pathname: removeAccents(
                                    contactItem.title.replace(/\s/g, "-").toLowerCase()
                                ),
                                search: `?u=${contactItem.UID}`,
                                state: {
                                    idItem: contactItem.UID,
                                },
                            }}
                        ></Link>
                        <ContactCard contactItem={contactItem} key={contactItem.created} />
                    </li>
                ))}
            </ul>
        </React.Fragment>
    );
};
export default ContactList;
